@@ -6,30 +6,32 @@
 
 #include "kurllabel.h"
 
-#include <QTimer>
 #include <QApplication>
 #include <QMouseEvent>
 #include <QPalette>
+#include <QTimer>
 
 class KUrlLabelPrivate
 {
 public:
     KUrlLabelPrivate(const QString &_url, KUrlLabel *_parent)
-        : parent(_parent),
-          url(_url),
-          tipText(url),
-          linkColor(_parent->palette().color(QPalette::Active, QPalette::Link)),
-          highlightedLinkColor(_parent->palette().color(QPalette::Active, QPalette::BrightText)),
-          cursor(nullptr),
-          textUnderlined(true),
-          realUnderlined(true),
-          useTips(false),
-          useCursor(false),
-          glowEnabled(true),
-          floatEnabled(false),
-          timer(new QTimer(parent))
+        : parent(_parent)
+        , url(_url)
+        , tipText(url)
+        , linkColor(_parent->palette().color(QPalette::Active, QPalette::Link))
+        , highlightedLinkColor(_parent->palette().color(QPalette::Active, QPalette::BrightText))
+        , cursor(nullptr)
+        , textUnderlined(true)
+        , realUnderlined(true)
+        , useTips(false)
+        , useCursor(false)
+        , glowEnabled(true)
+        , floatEnabled(false)
+        , timer(new QTimer(parent))
     {
-        QObject::connect(timer, &QTimer::timeout, parent, [this]() { updateColor(); });
+        QObject::connect(timer, &QTimer::timeout, parent, [this]() {
+            updateColor();
+        });
     }
 
     void updateColor()
@@ -69,8 +71,8 @@ public:
 };
 
 KUrlLabel::KUrlLabel(const QString &url, const QString &text, QWidget *parent)
-    : QLabel(!text.isNull() ? text : url, parent),
-      d(new KUrlLabelPrivate(url, this))
+    : QLabel(!text.isNull() ? text : url, parent)
+    , d(new KUrlLabelPrivate(url, this))
 {
     setFont(font());
     setCursor(QCursor(Qt::PointingHandCursor));
@@ -78,8 +80,8 @@ KUrlLabel::KUrlLabel(const QString &url, const QString &text, QWidget *parent)
 }
 
 KUrlLabel::KUrlLabel(QWidget *parent)
-    : QLabel(parent),
-      d(new KUrlLabelPrivate(QString(), this))
+    : QLabel(parent)
+    , d(new KUrlLabelPrivate(QString(), this))
 {
     setFont(font());
     setCursor(QCursor(Qt::PointingHandCursor));
@@ -98,23 +100,14 @@ void KUrlLabel::mouseReleaseEvent(QMouseEvent *event)
     switch (event->button()) {
     case Qt::LeftButton:
         Q_EMIT leftClickedUrl();
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-        Q_EMIT leftClickedUrl(d->url);
-#endif
         break;
 
     case Qt::MiddleButton:
         Q_EMIT middleClickedUrl();
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-        Q_EMIT middleClickedUrl(d->url);
-#endif
         break;
 
     case Qt::RightButton:
         Q_EMIT rightClickedUrl();
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-        Q_EMIT rightClickedUrl(d->url);
-#endif
         break;
 
     default:
@@ -139,7 +132,7 @@ void KUrlLabel::setUnderline(bool on)
 
 void KUrlLabel::setUrl(const QString &url)
 {
-    if (d->tipText == d->url) {   // update the tip as well
+    if (d->tipText == d->url) { // update the tip as well
         d->tipText = url;
         setUseTips(d->useTips);
     }
@@ -259,11 +252,10 @@ const QPixmap *KUrlLabel::alternatePixmap() const
     return &d->alternatePixmap;
 }
 
-void KUrlLabel::enterEvent(QEvent *event)
+void KUrlLabel::enterEvent(QEnterEvent *event)
 {
     QLabel::enterEvent(event);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
     if (!d->alternatePixmap.isNull()) {
         const auto currentPixmap = pixmap(Qt::ReturnByValue);
         if (!currentPixmap.isNull()) {
@@ -271,12 +263,6 @@ void KUrlLabel::enterEvent(QEvent *event)
             setPixmap(d->alternatePixmap);
         }
     }
-#else
-    if (!d->alternatePixmap.isNull() && pixmap()) {
-        d->realPixmap = *pixmap();
-        setPixmap(d->alternatePixmap);
-    }
-#endif
 
     if (d->glowEnabled || d->floatEnabled) {
         d->timer->stop();
@@ -290,21 +276,13 @@ void KUrlLabel::enterEvent(QEvent *event)
         }
     }
     Q_EMIT enteredUrl();
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-    Q_EMIT enteredUrl(d->url);
-#endif
 }
 
 void KUrlLabel::leaveEvent(QEvent *event)
 {
     QLabel::leaveEvent(event);
 
-    if (!d->alternatePixmap.isNull() &&
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
-        !pixmap(Qt::ReturnByValue).isNull()) {
-#else
-        pixmap()) {
-#endif
+    if (!d->alternatePixmap.isNull() && !pixmap(Qt::ReturnByValue).isNull()) {
         setPixmap(d->realPixmap);
     }
 
@@ -314,9 +292,6 @@ void KUrlLabel::leaveEvent(QEvent *event)
 
     setUnderline(d->realUnderlined);
     Q_EMIT leftUrl();
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-    Q_EMIT leftUrl(d->url);
-#endif
 }
 
 bool KUrlLabel::event(QEvent *event)
